CVS commit: src/sys/dev/pci/ixgbe

2022-01-23 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Mon Jan 24 01:57:52 UTC 2022

Modified Files:
src/sys/dev/pci/ixgbe: ixv.c

Log Message:
 Fix ixv.c rev. 1.176. Calculate 36bit counter correctly.


To generate a diff of this commit:
cvs rdiff -u -r1.176 -r1.177 src/sys/dev/pci/ixgbe/ixv.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/ixgbe/ixv.c
diff -u src/sys/dev/pci/ixgbe/ixv.c:1.176 src/sys/dev/pci/ixgbe/ixv.c:1.177
--- src/sys/dev/pci/ixgbe/ixv.c:1.176	Wed Jan 19 10:30:04 2022
+++ src/sys/dev/pci/ixgbe/ixv.c	Mon Jan 24 01:57:52 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: ixv.c,v 1.176 2022/01/19 10:30:04 msaitoh Exp $ */
+/* $NetBSD: ixv.c,v 1.177 2022/01/24 01:57:52 msaitoh Exp $ */
 
 /**
 
@@ -35,7 +35,7 @@
 /*$FreeBSD: head/sys/dev/ixgbe/if_ixv.c 331224 2018-03-19 20:55:05Z erj $*/
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: ixv.c,v 1.176 2022/01/19 10:30:04 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ixv.c,v 1.177 2022/01/24 01:57:52 msaitoh Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_inet.h"
@@ -2429,13 +2429,16 @@ ixv_init_stats(struct adapter *adapter)
 	(last) = current;\
 }
 
-#define UPDATE_STAT_36(lsb, msb, last, count)		\
-{			\
-	u64 cur_lsb = IXGBE_READ_REG(hw, (lsb));	\
-	u64 cur_msb = IXGBE_READ_REG(hw, (msb));	\
-	u64 current = ((cur_msb << 32) | cur_lsb);	\
-	count.ev_count += current - last;		\
-	(last) = current;\
+#define UPDATE_STAT_36(lsb, msb, last, count)		   	\
+{		   		\
+	u64 cur_lsb = IXGBE_READ_REG(hw, (lsb));		\
+	u64 cur_msb = IXGBE_READ_REG(hw, (msb));		\
+	u64 current = ((cur_msb << 32) | cur_lsb);		\
+	if (current < (last))	\
+		count.ev_count += current + __BIT(36) - (last);	\
+	else			\
+		count.ev_count += current - (last);		\
+	(last) = current;	\
 }
 
 /



CVS commit: src/sys/dev/pci/ixgbe

2022-01-23 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Mon Jan 24 01:57:52 UTC 2022

Modified Files:
src/sys/dev/pci/ixgbe: ixv.c

Log Message:
 Fix ixv.c rev. 1.176. Calculate 36bit counter correctly.


To generate a diff of this commit:
cvs rdiff -u -r1.176 -r1.177 src/sys/dev/pci/ixgbe/ixv.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/pci/ixgbe

2022-01-23 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Mon Jan 24 01:50:20 UTC 2022

Modified Files:
src/sys/dev/pci/ixgbe: ixgbe_vf.h

Log Message:
Use 32bit for 32bit counter.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/sys/dev/pci/ixgbe/ixgbe_vf.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/ixgbe/ixgbe_vf.h
diff -u src/sys/dev/pci/ixgbe/ixgbe_vf.h:1.16 src/sys/dev/pci/ixgbe/ixgbe_vf.h:1.17
--- src/sys/dev/pci/ixgbe/ixgbe_vf.h:1.16	Wed Jan 19 10:30:04 2022
+++ src/sys/dev/pci/ixgbe/ixgbe_vf.h	Mon Jan 24 01:50:19 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: ixgbe_vf.h,v 1.16 2022/01/19 10:30:04 msaitoh Exp $ */
+/* $NetBSD: ixgbe_vf.h,v 1.17 2022/01/24 01:50:19 msaitoh Exp $ */
 
 /**
   SPDX-License-Identifier: BSD-3-Clause
@@ -101,11 +101,11 @@ struct ixgbevf_hw_stats {
 	struct evcnt l4cs;
 	struct evcnt l4cs_bad;
 
-	u64 last_vfgprc;
-	u64 last_vfgptc;
+	u32 last_vfgprc;
+	u32 last_vfgptc;
 	u64 last_vfgorc;
 	u64 last_vfgotc;
-	u64 last_vfmprc;
+	u32 last_vfmprc;
 
 	struct evcnt vfgprc;
 	struct evcnt vfgptc;



CVS commit: src/sys/dev/pci/ixgbe

2022-01-23 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Mon Jan 24 01:50:20 UTC 2022

Modified Files:
src/sys/dev/pci/ixgbe: ixgbe_vf.h

Log Message:
Use 32bit for 32bit counter.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/sys/dev/pci/ixgbe/ixgbe_vf.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch

2022-01-23 Thread Maya Rashish
Module Name:src
Committed By:   maya
Date:   Mon Jan 24 00:15:09 UTC 2022

Modified Files:
src/sys/arch/amd64/conf: kern.ldscript.Xen
src/sys/arch/i386/conf: kern.ldscript.Xen

Log Message:
put .note.Xen into PT_NOTE

this is where grub 2.02 and possibly other things expect
to find it.
Fixes booting with grub2 on prgmr.com.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/amd64/conf/kern.ldscript.Xen
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/i386/conf/kern.ldscript.Xen

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amd64/conf/kern.ldscript.Xen
diff -u src/sys/arch/amd64/conf/kern.ldscript.Xen:1.17 src/sys/arch/amd64/conf/kern.ldscript.Xen:1.18
--- src/sys/arch/amd64/conf/kern.ldscript.Xen:1.17	Thu May 21 09:36:24 2020
+++ src/sys/arch/amd64/conf/kern.ldscript.Xen	Mon Jan 24 00:15:09 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: kern.ldscript.Xen,v 1.17 2020/05/21 09:36:24 jdolecek Exp $	*/
+/*	$NetBSD: kern.ldscript.Xen,v 1.18 2022/01/24 00:15:09 maya Exp $	*/
 
 #include "assym.h"
 
@@ -13,7 +13,7 @@ SECTIONS
 		*(.text.*)
 		*(.stub)
 		. = ALIGN(__PAGE_SIZE);
-	} =0xCC
+	} :main =0xCC
 	_etext = . ;
 	PROVIDE (etext = .) ;
 
@@ -80,5 +80,14 @@ SECTIONS
 	{
 		KEEP(*(.note.netbsd.ident));
 	}
+	.note.Xen :
+	{
+		KEEP(*(.note.Xen));
+	} :notes
 }
 
+PHDRS
+{
+	main PT_LOAD;
+	notes PT_NOTE;
+}

Index: src/sys/arch/i386/conf/kern.ldscript.Xen
diff -u src/sys/arch/i386/conf/kern.ldscript.Xen:1.16 src/sys/arch/i386/conf/kern.ldscript.Xen:1.17
--- src/sys/arch/i386/conf/kern.ldscript.Xen:1.16	Sun Jun 24 18:24:53 2018
+++ src/sys/arch/i386/conf/kern.ldscript.Xen	Mon Jan 24 00:15:09 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: kern.ldscript.Xen,v 1.16 2018/06/24 18:24:53 maxv Exp $	*/
+/*	$NetBSD: kern.ldscript.Xen,v 1.17 2022/01/24 00:15:09 maya Exp $	*/
 
 #include "assym.h"
 
@@ -12,7 +12,7 @@ SECTIONS
 		*(.text.*)
 		*(.stub)
 		. = ALIGN(__PAGE_SIZE);
-	} =0xCC
+	} :main =0xCC
 	_etext = . ;
 	PROVIDE (etext = .) ;
 
@@ -75,5 +75,14 @@ SECTIONS
 	{
 		KEEP(*(.note.netbsd.ident));
 	}
+	.note.Xen :
+	{
+		KEEP(*(.note.Xen));
+	} :notes
 }
 
+PHDRS
+{
+	main PT_LOAD;
+	notes PT_NOTE;
+}



CVS commit: src/sys/arch

2022-01-23 Thread Maya Rashish
Module Name:src
Committed By:   maya
Date:   Mon Jan 24 00:15:09 UTC 2022

Modified Files:
src/sys/arch/amd64/conf: kern.ldscript.Xen
src/sys/arch/i386/conf: kern.ldscript.Xen

Log Message:
put .note.Xen into PT_NOTE

this is where grub 2.02 and possibly other things expect
to find it.
Fixes booting with grub2 on prgmr.com.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/amd64/conf/kern.ldscript.Xen
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/i386/conf/kern.ldscript.Xen

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/make

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 22:12:16 UTC 2022

Modified Files:
src/usr.bin/make: make.h
Removed Files:
src/usr.bin/make: nonints.h

Log Message:
make: merge nonints.h into make.h

No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.289 -r1.290 src/usr.bin/make/make.h
cvs rdiff -u -r1.239 -r0 src/usr.bin/make/nonints.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/unit-tests/deptgt-main.exp
diff -u src/usr.bin/make/unit-tests/deptgt-main.exp:1.1 src/usr.bin/make/unit-tests/deptgt-main.exp:1.2
--- src/usr.bin/make/unit-tests/deptgt-main.exp:1.1	Sun Aug 16 12:07:51 2020
+++ src/usr.bin/make/unit-tests/deptgt-main.exp	Sun Jan 23 21:48:59 2022
@@ -1 +1,2 @@
+This target real-main is the one that is made.
 exit status 0
Index: src/usr.bin/make/unit-tests/directive-dinclude.exp
diff -u src/usr.bin/make/unit-tests/directive-dinclude.exp:1.1 src/usr.bin/make/unit-tests/directive-dinclude.exp:1.2
--- src/usr.bin/make/unit-tests/directive-dinclude.exp:1.1	Sun Sep 13 09:20:23 2020
+++ src/usr.bin/make/unit-tests/directive-dinclude.exp	Sun Jan 23 21:48:59 2022
@@ -1 +1,4 @@
-exit status 0
+make: "directive-dinclude-error.inc" line 1: Invalid line type
+make: Fatal errors encountered -- cannot continue
+make: stopped in unit-tests
+exit status 1
Index: src/usr.bin/make/unit-tests/directive-dinclude.mk
diff -u src/usr.bin/make/unit-tests/directive-dinclude.mk:1.1 src/usr.bin/make/unit-tests/directive-dinclude.mk:1.2
--- src/usr.bin/make/unit-tests/directive-dinclude.mk:1.1	Sun Sep 13 09:20:23 2020
+++ src/usr.bin/make/unit-tests/directive-dinclude.mk	Sun Jan 23 21:48:59 2022
@@ -1,9 +1,24 @@
-# $NetBSD: directive-dinclude.mk,v 1.1 2020/09/13 09:20:23 rillig Exp $
+# $NetBSD: directive-dinclude.mk,v 1.2 2022/01/23 21:48:59 rillig Exp $
 #
 # Tests for the .dinclude directive, which includes another file,
-# typically named .depend.
+# silently skipping it if it cannot be opened.  This is primarily used for
+# including '.depend' files, that's where the 'd' comes from.
+#
+# The 'silently skipping' only applies to the case where the file cannot be
+# opened.  Parse errors and other errors are handled the same way as in the
+# other .include directives.
+
+# No complaint that there is no such file.
+.dinclude "${.CURDIR}/directive-dinclude-nonexistent.inc"
+
+# No complaint either, even though the operating system error is ENOTDIR, not
+# ENOENT.
+.dinclude "${MAKEFILE}/subdir"
 
-# TODO: Implementation
+# Errors that are not related to opening the file are still reported.
+# expect: make: "directive-dinclude-error.inc" line 1: Invalid line type
+_!=	echo 'syntax error' > directive-dinclude-error.inc
+.dinclude "${.CURDIR}/directive-dinclude-error.inc"
+_!=	rm directive-dinclude-error.inc
 
-all:
-	@:;
+all: .PHONY
Index: src/usr.bin/make/unit-tests/directive-hyphen-include.exp
diff -u src/usr.bin/make/unit-tests/directive-hyphen-include.exp:1.1 src/usr.bin/make/unit-tests/directive-hyphen-include.exp:1.2
--- src/usr.bin/make/unit-tests/directive-hyphen-include.exp:1.1	Sun Sep 13 09:20:23 2020
+++ src/usr.bin/make/unit-tests/directive-hyphen-include.exp	Sun Jan 23 21:48:59 2022
@@ -1 +1,4 @@
-exit status 0
+make: "directive-hyphen-include-error.inc" line 1: Invalid line type
+make: Fatal errors encountered -- cannot continue
+make: stopped in unit-tests
+exit status 1
Index: src/usr.bin/make/unit-tests/directive-hyphen-include.mk
diff -u src/usr.bin/make/unit-tests/directive-hyphen-include.mk:1.1 src/usr.bin/make/unit-tests/directive-hyphen-include.mk:1.2
--- src/usr.bin/make/unit-tests/directive-hyphen-include.mk:1.1	Sun Sep 13 09:20:23 2020
+++ src/usr.bin/make/unit-tests/directive-hyphen-include.mk	Sun Jan 23 21:48:59 2022
@@ -1,9 +1,23 @@
-# $NetBSD: 

CVS commit: src/usr.bin/make/unit-tests

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 21:48:59 UTC 2022

Modified Files:
src/usr.bin/make/unit-tests: deptgt-main.exp deptgt-main.mk
directive-dinclude.exp directive-dinclude.mk
directive-hyphen-include.exp directive-hyphen-include.mk
directive-if.exp directive-if.mk directive-ifdef.exp
directive-ifdef.mk directive-sinclude.mk varmod-to-separator.mk
varname-dot-make-pid.mk varname-dot-make-ppid.mk

Log Message:
tests/make: add a few more tests


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/usr.bin/make/unit-tests/deptgt-main.exp \
src/usr.bin/make/unit-tests/directive-dinclude.exp \
src/usr.bin/make/unit-tests/directive-dinclude.mk \
src/usr.bin/make/unit-tests/directive-hyphen-include.exp \
src/usr.bin/make/unit-tests/directive-hyphen-include.mk
cvs rdiff -u -r1.3 -r1.4 src/usr.bin/make/unit-tests/deptgt-main.mk \
src/usr.bin/make/unit-tests/directive-ifdef.exp \
src/usr.bin/make/unit-tests/directive-sinclude.mk
cvs rdiff -u -r1.9 -r1.10 src/usr.bin/make/unit-tests/directive-if.exp \
src/usr.bin/make/unit-tests/varmod-to-separator.mk
cvs rdiff -u -r1.10 -r1.11 src/usr.bin/make/unit-tests/directive-if.mk
cvs rdiff -u -r1.4 -r1.5 src/usr.bin/make/unit-tests/directive-ifdef.mk
cvs rdiff -u -r1.2 -r1.3 src/usr.bin/make/unit-tests/varname-dot-make-pid.mk \
src/usr.bin/make/unit-tests/varname-dot-make-ppid.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/librefuse

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 21:07:28 UTC 2022

Modified Files:
src/lib/librefuse: refuse_compat.c
src/lib/librefuse/refuse: v30.c

Log Message:
librefuse: fix lint warnings about void function returning a value

lib/librefuse/refuse_compat.c(155):
error: void function fuse_unmount cannot return value [213]
lib/librefuse/refuse/v30.c(57):
error: void function fuse_destroy_v30 cannot return value [213]


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/lib/librefuse/refuse_compat.c
cvs rdiff -u -r1.1 -r1.2 src/lib/librefuse/refuse/v30.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/librefuse/refuse_compat.c
diff -u src/lib/librefuse/refuse_compat.c:1.2 src/lib/librefuse/refuse_compat.c:1.3
--- src/lib/librefuse/refuse_compat.c:1.2	Sat Jan 22 08:09:39 2022
+++ src/lib/librefuse/refuse_compat.c	Sun Jan 23 21:07:28 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: refuse_compat.c,v 1.2 2022/01/22 08:09:39 pho Exp $ */
+/* $NetBSD: refuse_compat.c,v 1.3 2022/01/23 21:07:28 rillig Exp $ */
 
 /*
  * Copyright (c) 2021 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include 
 #if !defined(lint)
-__RCSID("$NetBSD: refuse_compat.c,v 1.2 2022/01/22 08:09:39 pho Exp $");
+__RCSID("$NetBSD: refuse_compat.c,v 1.3 2022/01/23 21:07:28 rillig Exp $");
 #endif /* !lint */
 
 #include 
@@ -152,7 +152,7 @@ __warn_references(
 " include  for correct reference")
 void
 fuse_unmount(struct fuse* fuse) {
-return fuse_unmount_v30(fuse);
+fuse_unmount_v30(fuse);
 }
 
 /* librefuse once had a function fuse_unmount_compat22() which was an

Index: src/lib/librefuse/refuse/v30.c
diff -u src/lib/librefuse/refuse/v30.c:1.1 src/lib/librefuse/refuse/v30.c:1.2
--- src/lib/librefuse/refuse/v30.c:1.1	Sat Jan 22 08:09:40 2022
+++ src/lib/librefuse/refuse/v30.c	Sun Jan 23 21:07:28 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: v30.c,v 1.1 2022/01/22 08:09:40 pho Exp $ */
+/* $NetBSD: v30.c,v 1.2 2022/01/23 21:07:28 rillig Exp $ */
 
 /*
  * Copyright (c) 2021 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include 
 #if !defined(lint)
-__RCSID("$NetBSD: v30.c,v 1.1 2022/01/22 08:09:40 pho Exp $");
+__RCSID("$NetBSD: v30.c,v 1.2 2022/01/23 21:07:28 rillig Exp $");
 #endif /* !lint */
 
 #include 
@@ -54,7 +54,7 @@ fuse_new_v30(struct fuse_args *args,
 
 void
 fuse_destroy_v30(struct fuse *fuse) {
-return __fuse_destroy(fuse);
+__fuse_destroy(fuse);
 }
 
 int



CVS commit: src/lib/librefuse

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 21:07:28 UTC 2022

Modified Files:
src/lib/librefuse: refuse_compat.c
src/lib/librefuse/refuse: v30.c

Log Message:
librefuse: fix lint warnings about void function returning a value

lib/librefuse/refuse_compat.c(155):
error: void function fuse_unmount cannot return value [213]
lib/librefuse/refuse/v30.c(57):
error: void function fuse_destroy_v30 cannot return value [213]


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/lib/librefuse/refuse_compat.c
cvs rdiff -u -r1.1 -r1.2 src/lib/librefuse/refuse/v30.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/make/unit-tests

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 18:59:18 UTC 2022

Modified Files:
src/usr.bin/make/unit-tests: varmod-to-separator.exp
varmod-to-separator.mk

Log Message:
tests/make: add more tests for the modifier ':ts'


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/usr.bin/make/unit-tests/varmod-to-separator.exp
cvs rdiff -u -r1.8 -r1.9 src/usr.bin/make/unit-tests/varmod-to-separator.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/unit-tests/varmod-to-separator.exp
diff -u src/usr.bin/make/unit-tests/varmod-to-separator.exp:1.9 src/usr.bin/make/unit-tests/varmod-to-separator.exp:1.10
--- src/usr.bin/make/unit-tests/varmod-to-separator.exp:1.9	Sun Jan 23 18:00:53 2022
+++ src/usr.bin/make/unit-tests/varmod-to-separator.exp	Sun Jan 23 18:59:18 2022
@@ -16,6 +16,10 @@ make: Bad modifier ":ts\X" for variable 
 make: "varmod-to-separator.mk" line 213: Malformed conditional (${WORDS:ts\X})
 make: Bad modifier ":t\X" for variable "WORDS"
 make: "varmod-to-separator.mk" line 221: Malformed conditional (${WORDS:t\X} != "anything")
+make: Bad modifier ":ts\69" for variable ""
+make: "varmod-to-separator.mk" line 237: Malformed conditional (${:Ua b:ts\69})
+make: "varmod-to-separator.mk" line 246: Invalid character number at "1F60E}"
+make: "varmod-to-separator.mk" line 246: Malformed conditional (${:Ua b:ts\x1F60E})
 make: Fatal errors encountered -- cannot continue
 make: stopped in unit-tests
 exit status 1

Index: src/usr.bin/make/unit-tests/varmod-to-separator.mk
diff -u src/usr.bin/make/unit-tests/varmod-to-separator.mk:1.8 src/usr.bin/make/unit-tests/varmod-to-separator.mk:1.9
--- src/usr.bin/make/unit-tests/varmod-to-separator.mk:1.8	Sun Jan 23 18:00:53 2022
+++ src/usr.bin/make/unit-tests/varmod-to-separator.mk	Sun Jan 23 18:59:18 2022
@@ -1,4 +1,4 @@
-# $NetBSD: varmod-to-separator.mk,v 1.8 2022/01/23 18:00:53 rillig Exp $
+# $NetBSD: varmod-to-separator.mk,v 1.9 2022/01/23 18:59:18 rillig Exp $
 #
 # Tests for the :ts variable modifier, which joins the words of the variable
 # using an arbitrary character as word separator.
@@ -222,8 +222,29 @@ WORDS=	one two three four five six
 .  info This line is not reached.
 .endif
 
-# TODO: This modifier used to accept decimal numbers as well, in the form
-# ':ts\120'.  When has this been changed to octal, and what happens now
-# for ':ts\90' ('Z' in decimal ASCII, undefined in octal)?
 
-# TODO: :ts\x1F600
+# Since 2003.07.23.18.06.46 and before 2016.03.07.20.20.35, the modifier ':ts'
+# interpreted an "octal escape" as decimal if the first digit was not '0'.
+.if ${:Ua b:ts\61} != "a1b"	# decimal would have been "a=b"
+.  error
+.endif
+
+# Since the character escape is always interpreted as octal, let's see what
+# happens for non-octal digits.  From 2003.07.23.18.06.46 to
+# 2016.02.27.16.20.06, the result was '1E2', since 2016.03.07.20.20.35 make no
+# longer accepts this escape and complains.
+# expect: make: Bad modifier ":ts\69" for variable ""
+.if ${:Ua b:ts\69}
+.  error
+.else
+.  error
+.endif
+
+# Try whether bmake is Unicode-ready.
+# expect+2: Invalid character number at "1F60E}"
+# expect+1: Malformed conditional (${:Ua b:ts\x1F60E})
+.if ${:Ua b:ts\x1F60E}		# U+1F60E "smiling face with sunglasses"
+.  error
+.else
+.  error
+.endif



CVS commit: src/usr.bin/make/unit-tests

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 18:59:18 UTC 2022

Modified Files:
src/usr.bin/make/unit-tests: varmod-to-separator.exp
varmod-to-separator.mk

Log Message:
tests/make: add more tests for the modifier ':ts'


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/usr.bin/make/unit-tests/varmod-to-separator.exp
cvs rdiff -u -r1.8 -r1.9 src/usr.bin/make/unit-tests/varmod-to-separator.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/make/unit-tests

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 18:15:29 UTC 2022

Modified Files:
src/usr.bin/make/unit-tests: posix.mk

Log Message:
tests/make: run nested makes with -r to reduce side effects


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/usr.bin/make/unit-tests/posix.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/make/unit-tests

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 18:15:29 UTC 2022

Modified Files:
src/usr.bin/make/unit-tests: posix.mk

Log Message:
tests/make: run nested makes with -r to reduce side effects


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/usr.bin/make/unit-tests/posix.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/unit-tests/posix.mk
diff -u src/usr.bin/make/unit-tests/posix.mk:1.2 src/usr.bin/make/unit-tests/posix.mk:1.3
--- src/usr.bin/make/unit-tests/posix.mk:1.2	Sat Oct 24 08:34:59 2020
+++ src/usr.bin/make/unit-tests/posix.mk	Sun Jan 23 18:15:29 2022
@@ -1,4 +1,4 @@
-# $NetBSD: posix.mk,v 1.2 2020/10/24 08:34:59 rillig Exp $
+# $NetBSD: posix.mk,v 1.3 2022/01/23 18:15:29 rillig Exp $
 
 all:	x plus subs err
 
@@ -14,11 +14,10 @@ plus:
 
 subs:
 	@echo make -n
-	@${.MAKE} -f ${MAKEFILE} -n plus
+	@${.MAKE} -r -f ${MAKEFILE} -n plus
 	@echo make -n -j1
-	@${.MAKE} -f ${MAKEFILE} -n -j1 plus
+	@${.MAKE} -r -f ${MAKEFILE} -n -j1 plus
 
 err:
 	@(echo Now we expect an error...; exit 1)
 	@echo "Oops! you shouldn't see this!"
-



CVS commit: src

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 18:00:54 UTC 2022

Modified Files:
src/distrib/sets/lists/tests: mi
src/usr.bin/make/unit-tests: Makefile comment.mk
varmod-to-separator.exp varmod-to-separator.mk
Removed Files:
src/usr.bin/make/unit-tests: modts.exp modts.mk

Log Message:
tests/make: migrate modts to varmod-to-separator and explain


To generate a diff of this commit:
cvs rdiff -u -r1.1184 -r1.1185 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.299 -r1.300 src/usr.bin/make/unit-tests/Makefile
cvs rdiff -u -r1.3 -r1.4 src/usr.bin/make/unit-tests/comment.mk
cvs rdiff -u -r1.6 -r0 src/usr.bin/make/unit-tests/modts.exp
cvs rdiff -u -r1.8 -r0 src/usr.bin/make/unit-tests/modts.mk
cvs rdiff -u -r1.8 -r1.9 src/usr.bin/make/unit-tests/varmod-to-separator.exp
cvs rdiff -u -r1.7 -r1.8 src/usr.bin/make/unit-tests/varmod-to-separator.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/tests/mi
diff -u src/distrib/sets/lists/tests/mi:1.1184 src/distrib/sets/lists/tests/mi:1.1185
--- src/distrib/sets/lists/tests/mi:1.1184	Sun Jan 23 16:25:53 2022
+++ src/distrib/sets/lists/tests/mi	Sun Jan 23 18:00:53 2022
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1184 2022/01/23 16:25:53 rillig Exp $
+# $NetBSD: mi,v 1.1185 2022/01/23 18:00:53 rillig Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -5721,8 +5721,8 @@
 ./usr/tests/usr.bin/make/unit-tests/modmisc.mk	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/modorder.exptests-obsolete		obsolete
 ./usr/tests/usr.bin/make/unit-tests/modorder.mk	tests-obsolete		obsolete
-./usr/tests/usr.bin/make/unit-tests/modts.exp	tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/modts.mk	tests-usr.bin-tests	compattestfile,atf
+./usr/tests/usr.bin/make/unit-tests/modts.exp	tests-obsolete		obsolete,atf
+./usr/tests/usr.bin/make/unit-tests/modts.mk	tests-obsolete		obsolete,atf
 ./usr/tests/usr.bin/make/unit-tests/modword.exp	tests-obsolete		obsolete,atf
 ./usr/tests/usr.bin/make/unit-tests/modword.mk	tests-obsolete		obsolete,atf
 ./usr/tests/usr.bin/make/unit-tests/objdir-writable.exptests-usr.bin-tests	compattestfile,atf

Index: src/usr.bin/make/unit-tests/Makefile
diff -u src/usr.bin/make/unit-tests/Makefile:1.299 src/usr.bin/make/unit-tests/Makefile:1.300
--- src/usr.bin/make/unit-tests/Makefile:1.299	Sun Jan 23 16:25:54 2022
+++ src/usr.bin/make/unit-tests/Makefile	Sun Jan 23 18:00:53 2022
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.299 2022/01/23 16:25:54 rillig Exp $
+# $NetBSD: Makefile,v 1.300 2022/01/23 18:00:53 rillig Exp $
 #
 # Unit tests for make(1)
 #
@@ -218,7 +218,6 @@ TESTS+=		meta-cmd-cmp
 TESTS+=		moderrs
 TESTS+=		modmatch
 TESTS+=		modmisc
-TESTS+=		modts
 .if ${.MAKE.UID} > 0
 TESTS+=		objdir-writable
 .endif

Index: src/usr.bin/make/unit-tests/comment.mk
diff -u src/usr.bin/make/unit-tests/comment.mk:1.3 src/usr.bin/make/unit-tests/comment.mk:1.4
--- src/usr.bin/make/unit-tests/comment.mk:1.3	Sun Nov 15 14:07:53 2020
+++ src/usr.bin/make/unit-tests/comment.mk	Sun Jan 23 18:00:53 2022
@@ -1,4 +1,4 @@
-# $NetBSD: comment.mk,v 1.3 2020/11/15 14:07:53 rillig Exp $
+# $NetBSD: comment.mk,v 1.4 2022/01/23 18:00:53 rillig Exp $
 #
 # Demonstrate how comments are written in makefiles.
 
@@ -15,7 +15,9 @@ on and on.
  # Comments can be indented with spaces, but that is rather unusual.
 
 	# Comments can be indented with a tab.
-	# These are not shell commands, they are just makefile comments.
+	# Since parse.c 1.127 from 2007-01-01, these are not shell commands,
+	# they are just makefile comments.  Before that commit, these comments
+	# triggered the error message "Unassociated shell command".
 
 .if 1			# There can be comments after conditions.
 .endif			# And after the closing directive.

Index: src/usr.bin/make/unit-tests/varmod-to-separator.exp
diff -u src/usr.bin/make/unit-tests/varmod-to-separator.exp:1.8 src/usr.bin/make/unit-tests/varmod-to-separator.exp:1.9
--- src/usr.bin/make/unit-tests/varmod-to-separator.exp:1.8	Thu Dec  9 20:27:01 2021
+++ src/usr.bin/make/unit-tests/varmod-to-separator.exp	Sun Jan 23 18:00:53 2022
@@ -1,19 +1,21 @@
-make: "varmod-to-separator.mk" line 107: Invalid character number at "400:tu}"
-make: "varmod-to-separator.mk" line 107: Malformed conditional (${WORDS:[1..3]:ts\400:tu})
-make: "varmod-to-separator.mk" line 121: Invalid character number at "100:tu}"
-make: "varmod-to-separator.mk" line 121: Malformed conditional (${WORDS:[1..3]:ts\x100:tu})
+make: "varmod-to-separator.mk" line 153: Invalid character number at "400:tu}"
+make: "varmod-to-separator.mk" line 153: Malformed conditional (${WORDS:[1..3]:ts\400:tu})
+make: "varmod-to-separator.mk" line 167: Invalid character number at "100:tu}"
+make: "varmod-to-separator.mk" line 167: 

CVS commit: src

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 18:00:54 UTC 2022

Modified Files:
src/distrib/sets/lists/tests: mi
src/usr.bin/make/unit-tests: Makefile comment.mk
varmod-to-separator.exp varmod-to-separator.mk
Removed Files:
src/usr.bin/make/unit-tests: modts.exp modts.mk

Log Message:
tests/make: migrate modts to varmod-to-separator and explain


To generate a diff of this commit:
cvs rdiff -u -r1.1184 -r1.1185 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.299 -r1.300 src/usr.bin/make/unit-tests/Makefile
cvs rdiff -u -r1.3 -r1.4 src/usr.bin/make/unit-tests/comment.mk
cvs rdiff -u -r1.6 -r0 src/usr.bin/make/unit-tests/modts.exp
cvs rdiff -u -r1.8 -r0 src/usr.bin/make/unit-tests/modts.mk
cvs rdiff -u -r1.8 -r1.9 src/usr.bin/make/unit-tests/varmod-to-separator.exp
cvs rdiff -u -r1.7 -r1.8 src/usr.bin/make/unit-tests/varmod-to-separator.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/doc

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 16:48:37 UTC 2022

Modified Files:
src/doc: 3RDPARTY CHANGES

Log Message:
new tmux


To generate a diff of this commit:
cvs rdiff -u -r1.1831 -r1.1832 src/doc/3RDPARTY
cvs rdiff -u -r1.2857 -r1.2858 src/doc/CHANGES

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/3RDPARTY
diff -u src/doc/3RDPARTY:1.1831 src/doc/3RDPARTY:1.1832
--- src/doc/3RDPARTY:1.1831	Fri Jan 21 10:07:33 2022
+++ src/doc/3RDPARTY	Sun Jan 23 11:48:37 2022
@@ -1,4 +1,4 @@
-#	$NetBSD: 3RDPARTY,v 1.1831 2022/01/21 15:07:33 wiz Exp $
+#	$NetBSD: 3RDPARTY,v 1.1832 2022/01/23 16:48:37 christos Exp $
 #
 # This file contains a list of the software that has been integrated into
 # NetBSD where we are not the primary maintainer.
@@ -1370,12 +1370,12 @@ perhaps this implementation should be ke
 purposes.
 
 Package:	tmux
-Version:	3.2
+Version:	3.2a
 Current Vers:	3.2a
 Maintainer:	Nicholas Marriott 
 Archive site:	https://github.com/tmux/tmux
 Home page:	http://tmux.github.io
-Date: 		2020-05-04
+Date: 		2022-01-23
 Mailing List:	tmux-us...@googlegroups.com
 Responsible:	christos
 License:	BSD

Index: src/doc/CHANGES
diff -u src/doc/CHANGES:1.2857 src/doc/CHANGES:1.2858
--- src/doc/CHANGES:1.2857	Tue Jan 11 05:07:23 2022
+++ src/doc/CHANGES	Sun Jan 23 11:48:37 2022
@@ -1,4 +1,4 @@
-# LIST OF CHANGES FROM LAST RELEASE:			<$Revision: 1.2857 $>
+# LIST OF CHANGES FROM LAST RELEASE:			<$Revision: 1.2858 $>
 #
 #
 # [Note: This file does not mention every change made to the NetBSD source tree.
@@ -467,3 +467,4 @@ Changes from NetBSD 9.0 to NetBSD 10.0:
 	OpenSSL: Imported 1.1.1m. [christos 20220107]
 	sysinst(8): Allow configuring IEEE 802.11 / Wi-Fi devices with
 		WPA or open networks. [nia 20220111]
+	tmux(1): Imported 3.2a. [christos 20220123]



CVS commit: src/doc

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 16:48:37 UTC 2022

Modified Files:
src/doc: 3RDPARTY CHANGES

Log Message:
new tmux


To generate a diff of this commit:
cvs rdiff -u -r1.1831 -r1.1832 src/doc/3RDPARTY
cvs rdiff -u -r1.2857 -r1.2858 src/doc/CHANGES

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/tmux

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 16:47:46 UTC 2022

Modified Files:
src/external/bsd/tmux/dist: cmd-display-menu.c cmd-new-session.c
format.c input-keys.c input.c key-bindings.c resize.c screen.c
server-client.c status.c tmux.1 tmux.c tmux.h tty-keys.c tty-term.c
tty.c window-buffer.c window-copy.c window.c
src/external/bsd/tmux/usr.bin/tmux: Makefile

Log Message:
merge changes between tmux-3.2 and tmux-3.2a


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/external/bsd/tmux/dist/cmd-display-menu.c \
src/external/bsd/tmux/dist/resize.c
cvs rdiff -u -r1.9 -r1.10 src/external/bsd/tmux/dist/cmd-new-session.c \
src/external/bsd/tmux/dist/server-client.c
cvs rdiff -u -r1.12 -r1.13 src/external/bsd/tmux/dist/format.c \
src/external/bsd/tmux/dist/screen.c src/external/bsd/tmux/dist/tmux.c
cvs rdiff -u -r1.11 -r1.12 src/external/bsd/tmux/dist/input-keys.c
cvs rdiff -u -r1.15 -r1.16 src/external/bsd/tmux/dist/input.c \
src/external/bsd/tmux/dist/tty-keys.c
cvs rdiff -u -r1.10 -r1.11 src/external/bsd/tmux/dist/key-bindings.c
cvs rdiff -u -r1.13 -r1.14 src/external/bsd/tmux/dist/status.c \
src/external/bsd/tmux/dist/window-copy.c
cvs rdiff -u -r1.14 -r1.15 src/external/bsd/tmux/dist/tmux.1 \
src/external/bsd/tmux/dist/tty-term.c src/external/bsd/tmux/dist/window.c
cvs rdiff -u -r1.19 -r1.20 src/external/bsd/tmux/dist/tmux.h
cvs rdiff -u -r1.8 -r1.9 src/external/bsd/tmux/dist/tty.c
cvs rdiff -u -r1.7 -r1.8 src/external/bsd/tmux/dist/window-buffer.c
cvs rdiff -u -r1.27 -r1.28 src/external/bsd/tmux/usr.bin/tmux/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/tmux/dist/cmd-display-menu.c
diff -u src/external/bsd/tmux/dist/cmd-display-menu.c:1.3 src/external/bsd/tmux/dist/cmd-display-menu.c:1.4
--- src/external/bsd/tmux/dist/cmd-display-menu.c:1.3	Sun Apr 18 10:01:29 2021
+++ src/external/bsd/tmux/dist/cmd-display-menu.c	Sun Jan 23 11:47:46 2022
@@ -205,7 +205,7 @@ cmd_display_menu_get_position(struct cli
 	if (xp == NULL || strcmp(xp, "C") == 0)
 		xp = "#{popup_centre_x}";
 	else if (strcmp(xp, "R") == 0)
-		xp = "#{popup_right}";
+		xp = "#{popup_pane_right}";
 	else if (strcmp(xp, "P") == 0)
 		xp = "#{popup_pane_left}";
 	else if (strcmp(xp, "M") == 0)
Index: src/external/bsd/tmux/dist/resize.c
diff -u src/external/bsd/tmux/dist/resize.c:1.3 src/external/bsd/tmux/dist/resize.c:1.4
--- src/external/bsd/tmux/dist/resize.c:1.3	Sat Apr 17 16:42:09 2021
+++ src/external/bsd/tmux/dist/resize.c	Sun Jan 23 11:47:46 2022
@@ -108,17 +108,19 @@ clients_with_window(struct window *w)
 }
 
 static int
-clients_calculate_size(int type, int current, struct session *s,
-struct window *w, int (*skip_client)(struct client *, int, int,
-struct session *, struct window *), u_int *sx, u_int *sy, u_int *xpixel,
-u_int *ypixel)
+clients_calculate_size(int type, int current, struct client *c,
+struct session *s, struct window *w, int (*skip_client)(struct client *,
+int, int, struct session *, struct window *), u_int *sx, u_int *sy,
+u_int *xpixel, u_int *ypixel)
 {
 	struct client	*loop;
 	u_int		 cx, cy, n = 0;
 
 	/* Manual windows do not have their size changed based on a client. */
-	if (type == WINDOW_SIZE_MANUAL)
+	if (type == WINDOW_SIZE_MANUAL) {
+		log_debug("%s: type is manual", __func__);
 		return (0);
+	}
 
 	/*
 	 * Start comparing with 0 for largest and UINT_MAX for smallest or
@@ -134,23 +136,29 @@ clients_calculate_size(int type, int cur
 	 * For latest, count the number of clients with this window. We only
 	 * care if there is more than one.
 	 */
-	if (type == WINDOW_SIZE_LATEST)
+	if (type == WINDOW_SIZE_LATEST && w != NULL)
 		n = clients_with_window(w);
 
 	/* Loop over the clients and work out the size. */
 	TAILQ_FOREACH(loop, , entry) {
-		if (ignore_client_size(loop))
+		if (loop != c && ignore_client_size(loop)) {
+			log_debug("%s: ignoring %s", __func__, loop->name);
 			continue;
-		if (skip_client(loop, type, current, s, w))
+		}
+		if (loop != c && skip_client(loop, type, current, s, w)) {
+			log_debug("%s: skipping %s", __func__, loop->name);
 			continue;
+		}
 
 		/*
 		 * If there are multiple clients attached, only accept the
 		 * latest client; otherwise let the only client be chosen as
 		 * for smallest.
 		 */
-		if (type == WINDOW_SIZE_LATEST && n > 1 && loop != w->latest)
+		if (type == WINDOW_SIZE_LATEST && n > 1 && loop != w->latest) {
+			log_debug("%s: %s is not latest", __func__, loop->name);
 			continue;
+		}
 
 		/* Work out this client's size. */
 		cx = loop->tty.sx;
@@ -175,16 +183,24 @@ clients_calculate_size(int type, int cur
 			*xpixel = loop->tty.xpixel;
 			*ypixel = loop->tty.ypixel;
 		}
+		log_debug("%s: after %s (%ux%u), size is %ux%u", __func__,
+		loop->name, cx, cy, *sx, *sy);
 	}
 
 	/* Return 

CVS commit: src/external/bsd/tmux

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 16:47:46 UTC 2022

Modified Files:
src/external/bsd/tmux/dist: cmd-display-menu.c cmd-new-session.c
format.c input-keys.c input.c key-bindings.c resize.c screen.c
server-client.c status.c tmux.1 tmux.c tmux.h tty-keys.c tty-term.c
tty.c window-buffer.c window-copy.c window.c
src/external/bsd/tmux/usr.bin/tmux: Makefile

Log Message:
merge changes between tmux-3.2 and tmux-3.2a


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/external/bsd/tmux/dist/cmd-display-menu.c \
src/external/bsd/tmux/dist/resize.c
cvs rdiff -u -r1.9 -r1.10 src/external/bsd/tmux/dist/cmd-new-session.c \
src/external/bsd/tmux/dist/server-client.c
cvs rdiff -u -r1.12 -r1.13 src/external/bsd/tmux/dist/format.c \
src/external/bsd/tmux/dist/screen.c src/external/bsd/tmux/dist/tmux.c
cvs rdiff -u -r1.11 -r1.12 src/external/bsd/tmux/dist/input-keys.c
cvs rdiff -u -r1.15 -r1.16 src/external/bsd/tmux/dist/input.c \
src/external/bsd/tmux/dist/tty-keys.c
cvs rdiff -u -r1.10 -r1.11 src/external/bsd/tmux/dist/key-bindings.c
cvs rdiff -u -r1.13 -r1.14 src/external/bsd/tmux/dist/status.c \
src/external/bsd/tmux/dist/window-copy.c
cvs rdiff -u -r1.14 -r1.15 src/external/bsd/tmux/dist/tmux.1 \
src/external/bsd/tmux/dist/tty-term.c src/external/bsd/tmux/dist/window.c
cvs rdiff -u -r1.19 -r1.20 src/external/bsd/tmux/dist/tmux.h
cvs rdiff -u -r1.8 -r1.9 src/external/bsd/tmux/dist/tty.c
cvs rdiff -u -r1.7 -r1.8 src/external/bsd/tmux/dist/window-buffer.c
cvs rdiff -u -r1.27 -r1.28 src/external/bsd/tmux/usr.bin/tmux/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS import: src/external/bsd/tmux/dist

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 16:45:06 UTC 2022

Update of /cvsroot/src/external/bsd/tmux/dist
In directory ivanova.netbsd.org:/tmp/cvs-serv4858

Log Message:
Import tmux-3.2a:

CHANGES FROM 3.2 TO 3.2a

* Add an "always" value for the "extended-keys" option; if set then tmux will
  forward extended keys to applications even if they do not request them.

* Add a "mouse" terminal feature so tmux can enable the mouse on terminals
  where it is known to be supported even if terminfo(5) says otherwise.

* Do not expand the filename given to -f so it can contain colons.

* Fixes for problems with extended keys and modifiers, scroll region,
  source-file, crosscompiling, format modifiers and other minor issues.

Status:

Vendor Tag: TMUX
Release Tags:   tmux-3-2a

U src/external/bsd/tmux/dist/Makefile.am
U src/external/bsd/tmux/dist/configure
U src/external/bsd/tmux/dist/configure.ac
U src/external/bsd/tmux/dist/aclocal.m4
U src/external/bsd/tmux/dist/Makefile.in
U src/external/bsd/tmux/dist/COPYING
U src/external/bsd/tmux/dist/README
U src/external/bsd/tmux/dist/cmd-parse.c
U src/external/bsd/tmux/dist/alerts.c
U src/external/bsd/tmux/dist/arguments.c
U src/external/bsd/tmux/dist/attributes.c
U src/external/bsd/tmux/dist/cfg.c
U src/external/bsd/tmux/dist/client.c
U src/external/bsd/tmux/dist/cmd-attach-session.c
U src/external/bsd/tmux/dist/cmd-bind-key.c
U src/external/bsd/tmux/dist/cmd-break-pane.c
U src/external/bsd/tmux/dist/cmd-capture-pane.c
U src/external/bsd/tmux/dist/cmd-choose-tree.c
U src/external/bsd/tmux/dist/cmd-command-prompt.c
U src/external/bsd/tmux/dist/cmd.c
U src/external/bsd/tmux/dist/cmd-confirm-before.c
U src/external/bsd/tmux/dist/cmd-copy-mode.c
U src/external/bsd/tmux/dist/cmd-detach-client.c
C src/external/bsd/tmux/dist/cmd-display-menu.c
U src/external/bsd/tmux/dist/cmd-display-message.c
U src/external/bsd/tmux/dist/cmd-display-panes.c
U src/external/bsd/tmux/dist/cmd-find-window.c
U src/external/bsd/tmux/dist/cmd-find.c
U src/external/bsd/tmux/dist/cmd-if-shell.c
U src/external/bsd/tmux/dist/cmd-join-pane.c
U src/external/bsd/tmux/dist/cmd-kill-pane.c
U src/external/bsd/tmux/dist/cmd-kill-server.c
U src/external/bsd/tmux/dist/cmd-kill-session.c
U src/external/bsd/tmux/dist/cmd-kill-window.c
U src/external/bsd/tmux/dist/cmd-list-buffers.c
U src/external/bsd/tmux/dist/cmd-list-clients.c
U src/external/bsd/tmux/dist/cmd-list-keys.c
U src/external/bsd/tmux/dist/cmd-list-panes.c
U src/external/bsd/tmux/dist/cmd-list-sessions.c
U src/external/bsd/tmux/dist/cmd-list-windows.c
U src/external/bsd/tmux/dist/cmd-load-buffer.c
U src/external/bsd/tmux/dist/cmd-lock-server.c
U src/external/bsd/tmux/dist/cmd-move-window.c
C src/external/bsd/tmux/dist/cmd-new-session.c
U src/external/bsd/tmux/dist/cmd-new-window.c
U src/external/bsd/tmux/dist/cmd-parse.y
U src/external/bsd/tmux/dist/cmd-paste-buffer.c
U src/external/bsd/tmux/dist/cmd-pipe-pane.c
U src/external/bsd/tmux/dist/cmd-queue.c
U src/external/bsd/tmux/dist/cmd-refresh-client.c
U src/external/bsd/tmux/dist/cmd-rename-session.c
U src/external/bsd/tmux/dist/cmd-rename-window.c
U src/external/bsd/tmux/dist/cmd-resize-pane.c
U src/external/bsd/tmux/dist/cmd-resize-window.c
U src/external/bsd/tmux/dist/cmd-respawn-pane.c
U src/external/bsd/tmux/dist/cmd-respawn-window.c
U src/external/bsd/tmux/dist/cmd-rotate-window.c
U src/external/bsd/tmux/dist/file.c
U src/external/bsd/tmux/dist/cmd-run-shell.c
U src/external/bsd/tmux/dist/cmd-save-buffer.c
U src/external/bsd/tmux/dist/cmd-select-layout.c
U src/external/bsd/tmux/dist/cmd-select-pane.c
U src/external/bsd/tmux/dist/cmd-select-window.c
U src/external/bsd/tmux/dist/cmd-send-keys.c
U src/external/bsd/tmux/dist/cmd-set-buffer.c
U src/external/bsd/tmux/dist/cmd-set-environment.c
U src/external/bsd/tmux/dist/cmd-set-option.c
U src/external/bsd/tmux/dist/cmd-show-environment.c
U src/external/bsd/tmux/dist/cmd-show-messages.c
U src/external/bsd/tmux/dist/cmd-show-options.c
U src/external/bsd/tmux/dist/cmd-source-file.c
U src/external/bsd/tmux/dist/cmd-split-window.c
U src/external/bsd/tmux/dist/cmd-swap-pane.c
U src/external/bsd/tmux/dist/cmd-swap-window.c
U src/external/bsd/tmux/dist/cmd-switch-client.c
U src/external/bsd/tmux/dist/cmd-unbind-key.c
U src/external/bsd/tmux/dist/cmd-wait-for.c
U src/external/bsd/tmux/dist/colour.c
U src/external/bsd/tmux/dist/compat.h
U src/external/bsd/tmux/dist/control-notify.c
U src/external/bsd/tmux/dist/control.c
U src/external/bsd/tmux/dist/environ.c
C src/external/bsd/tmux/dist/format.c
U src/external/bsd/tmux/dist/format-draw.c
U src/external/bsd/tmux/dist/grid-reader.c
U src/external/bsd/tmux/dist/grid-view.c
U src/external/bsd/tmux/dist/grid.c
C src/external/bsd/tmux/dist/input-keys.c
C src/external/bsd/tmux/dist/input.c
U src/external/bsd/tmux/dist/job.c
C src/external/bsd/tmux/dist/key-bindings.c
U src/external/bsd/tmux/dist/key-string.c
U src/external/bsd/tmux/dist/layout-custom.c
U 

CVS import: src/external/bsd/tmux/dist

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 16:45:06 UTC 2022

Update of /cvsroot/src/external/bsd/tmux/dist
In directory ivanova.netbsd.org:/tmp/cvs-serv4858

Log Message:
Import tmux-3.2a:

CHANGES FROM 3.2 TO 3.2a

* Add an "always" value for the "extended-keys" option; if set then tmux will
  forward extended keys to applications even if they do not request them.

* Add a "mouse" terminal feature so tmux can enable the mouse on terminals
  where it is known to be supported even if terminfo(5) says otherwise.

* Do not expand the filename given to -f so it can contain colons.

* Fixes for problems with extended keys and modifiers, scroll region,
  source-file, crosscompiling, format modifiers and other minor issues.

Status:

Vendor Tag: TMUX
Release Tags:   tmux-3-2a

U src/external/bsd/tmux/dist/Makefile.am
U src/external/bsd/tmux/dist/configure
U src/external/bsd/tmux/dist/configure.ac
U src/external/bsd/tmux/dist/aclocal.m4
U src/external/bsd/tmux/dist/Makefile.in
U src/external/bsd/tmux/dist/COPYING
U src/external/bsd/tmux/dist/README
U src/external/bsd/tmux/dist/cmd-parse.c
U src/external/bsd/tmux/dist/alerts.c
U src/external/bsd/tmux/dist/arguments.c
U src/external/bsd/tmux/dist/attributes.c
U src/external/bsd/tmux/dist/cfg.c
U src/external/bsd/tmux/dist/client.c
U src/external/bsd/tmux/dist/cmd-attach-session.c
U src/external/bsd/tmux/dist/cmd-bind-key.c
U src/external/bsd/tmux/dist/cmd-break-pane.c
U src/external/bsd/tmux/dist/cmd-capture-pane.c
U src/external/bsd/tmux/dist/cmd-choose-tree.c
U src/external/bsd/tmux/dist/cmd-command-prompt.c
U src/external/bsd/tmux/dist/cmd.c
U src/external/bsd/tmux/dist/cmd-confirm-before.c
U src/external/bsd/tmux/dist/cmd-copy-mode.c
U src/external/bsd/tmux/dist/cmd-detach-client.c
C src/external/bsd/tmux/dist/cmd-display-menu.c
U src/external/bsd/tmux/dist/cmd-display-message.c
U src/external/bsd/tmux/dist/cmd-display-panes.c
U src/external/bsd/tmux/dist/cmd-find-window.c
U src/external/bsd/tmux/dist/cmd-find.c
U src/external/bsd/tmux/dist/cmd-if-shell.c
U src/external/bsd/tmux/dist/cmd-join-pane.c
U src/external/bsd/tmux/dist/cmd-kill-pane.c
U src/external/bsd/tmux/dist/cmd-kill-server.c
U src/external/bsd/tmux/dist/cmd-kill-session.c
U src/external/bsd/tmux/dist/cmd-kill-window.c
U src/external/bsd/tmux/dist/cmd-list-buffers.c
U src/external/bsd/tmux/dist/cmd-list-clients.c
U src/external/bsd/tmux/dist/cmd-list-keys.c
U src/external/bsd/tmux/dist/cmd-list-panes.c
U src/external/bsd/tmux/dist/cmd-list-sessions.c
U src/external/bsd/tmux/dist/cmd-list-windows.c
U src/external/bsd/tmux/dist/cmd-load-buffer.c
U src/external/bsd/tmux/dist/cmd-lock-server.c
U src/external/bsd/tmux/dist/cmd-move-window.c
C src/external/bsd/tmux/dist/cmd-new-session.c
U src/external/bsd/tmux/dist/cmd-new-window.c
U src/external/bsd/tmux/dist/cmd-parse.y
U src/external/bsd/tmux/dist/cmd-paste-buffer.c
U src/external/bsd/tmux/dist/cmd-pipe-pane.c
U src/external/bsd/tmux/dist/cmd-queue.c
U src/external/bsd/tmux/dist/cmd-refresh-client.c
U src/external/bsd/tmux/dist/cmd-rename-session.c
U src/external/bsd/tmux/dist/cmd-rename-window.c
U src/external/bsd/tmux/dist/cmd-resize-pane.c
U src/external/bsd/tmux/dist/cmd-resize-window.c
U src/external/bsd/tmux/dist/cmd-respawn-pane.c
U src/external/bsd/tmux/dist/cmd-respawn-window.c
U src/external/bsd/tmux/dist/cmd-rotate-window.c
U src/external/bsd/tmux/dist/file.c
U src/external/bsd/tmux/dist/cmd-run-shell.c
U src/external/bsd/tmux/dist/cmd-save-buffer.c
U src/external/bsd/tmux/dist/cmd-select-layout.c
U src/external/bsd/tmux/dist/cmd-select-pane.c
U src/external/bsd/tmux/dist/cmd-select-window.c
U src/external/bsd/tmux/dist/cmd-send-keys.c
U src/external/bsd/tmux/dist/cmd-set-buffer.c
U src/external/bsd/tmux/dist/cmd-set-environment.c
U src/external/bsd/tmux/dist/cmd-set-option.c
U src/external/bsd/tmux/dist/cmd-show-environment.c
U src/external/bsd/tmux/dist/cmd-show-messages.c
U src/external/bsd/tmux/dist/cmd-show-options.c
U src/external/bsd/tmux/dist/cmd-source-file.c
U src/external/bsd/tmux/dist/cmd-split-window.c
U src/external/bsd/tmux/dist/cmd-swap-pane.c
U src/external/bsd/tmux/dist/cmd-swap-window.c
U src/external/bsd/tmux/dist/cmd-switch-client.c
U src/external/bsd/tmux/dist/cmd-unbind-key.c
U src/external/bsd/tmux/dist/cmd-wait-for.c
U src/external/bsd/tmux/dist/colour.c
U src/external/bsd/tmux/dist/compat.h
U src/external/bsd/tmux/dist/control-notify.c
U src/external/bsd/tmux/dist/control.c
U src/external/bsd/tmux/dist/environ.c
C src/external/bsd/tmux/dist/format.c
U src/external/bsd/tmux/dist/format-draw.c
U src/external/bsd/tmux/dist/grid-reader.c
U src/external/bsd/tmux/dist/grid-view.c
U src/external/bsd/tmux/dist/grid.c
C src/external/bsd/tmux/dist/input-keys.c
C src/external/bsd/tmux/dist/input.c
U src/external/bsd/tmux/dist/job.c
C src/external/bsd/tmux/dist/key-bindings.c
U src/external/bsd/tmux/dist/key-string.c
U src/external/bsd/tmux/dist/layout-custom.c
U 

CVS commit: src

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 16:25:54 UTC 2022

Modified Files:
src/distrib/sets/lists/tests: mi
src/usr.bin/make/unit-tests: Makefile
Added Files:
src/usr.bin/make/unit-tests: var-scope-cmdline.exp var-scope-cmdline.mk
var-scope-env.exp var-scope-env.mk var-scope-global.exp
var-scope-global.mk var-scope-local-legacy.exp
var-scope-local-legacy.mk var-scope-local.exp var-scope-local.mk
var-scope.exp var-scope.mk
Removed Files:
src/usr.bin/make/unit-tests: var-class-cmdline.exp var-class-cmdline.mk
var-class-env.exp var-class-env.mk var-class-global.exp
var-class-global.mk var-class-local-legacy.exp
var-class-local-legacy.mk var-class-local.exp var-class-local.mk
var-class.exp var-class.mk

Log Message:
tests/make: rename var-class to var-scope

There is no such concept as a "variable class" in make, these tests
focus on the variable scope instead.


To generate a diff of this commit:
cvs rdiff -u -r1.1183 -r1.1184 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.298 -r1.299 src/usr.bin/make/unit-tests/Makefile
cvs rdiff -u -r1.4 -r0 src/usr.bin/make/unit-tests/var-class-cmdline.exp
cvs rdiff -u -r1.5 -r0 src/usr.bin/make/unit-tests/var-class-cmdline.mk \
src/usr.bin/make/unit-tests/var-class-local.mk
cvs rdiff -u -r1.1 -r0 src/usr.bin/make/unit-tests/var-class-env.exp \
src/usr.bin/make/unit-tests/var-class-global.exp \
src/usr.bin/make/unit-tests/var-class-local-legacy.exp \
src/usr.bin/make/unit-tests/var-class.exp
cvs rdiff -u -r1.2 -r0 src/usr.bin/make/unit-tests/var-class-env.mk \
src/usr.bin/make/unit-tests/var-class-local-legacy.mk \
src/usr.bin/make/unit-tests/var-class.mk
cvs rdiff -u -r1.3 -r0 src/usr.bin/make/unit-tests/var-class-global.mk \
src/usr.bin/make/unit-tests/var-class-local.exp
cvs rdiff -u -r0 -r1.1 src/usr.bin/make/unit-tests/var-scope-cmdline.exp \
src/usr.bin/make/unit-tests/var-scope-cmdline.mk \
src/usr.bin/make/unit-tests/var-scope-env.exp \
src/usr.bin/make/unit-tests/var-scope-env.mk \
src/usr.bin/make/unit-tests/var-scope-global.exp \
src/usr.bin/make/unit-tests/var-scope-global.mk \
src/usr.bin/make/unit-tests/var-scope-local-legacy.exp \
src/usr.bin/make/unit-tests/var-scope-local-legacy.mk \
src/usr.bin/make/unit-tests/var-scope-local.exp \
src/usr.bin/make/unit-tests/var-scope-local.mk \
src/usr.bin/make/unit-tests/var-scope.exp \
src/usr.bin/make/unit-tests/var-scope.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/tests/mi
diff -u src/distrib/sets/lists/tests/mi:1.1183 src/distrib/sets/lists/tests/mi:1.1184
--- src/distrib/sets/lists/tests/mi:1.1183	Sun Jan 23 16:09:38 2022
+++ src/distrib/sets/lists/tests/mi	Sun Jan 23 16:25:53 2022
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1183 2022/01/23 16:09:38 rillig Exp $
+# $NetBSD: mi,v 1.1184 2022/01/23 16:25:53 rillig Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -5931,18 +5931,18 @@
 ./usr/tests/usr.bin/make/unit-tests/unexport.mk	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/use-inference.exptests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/use-inference.mktests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-cmdline.exp			tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-cmdline.mk			tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-env.exptests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-env.mktests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-global.exp			tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-global.mktests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-local-legacy.exp			tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-local-legacy.mk			tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-local.exptests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class-local.mktests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class.exptests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/var-class.mktests-usr.bin-tests	compattestfile,atf
+./usr/tests/usr.bin/make/unit-tests/var-class-cmdline.exp			tests-obsolete		obsolete,atf
+./usr/tests/usr.bin/make/unit-tests/var-class-cmdline.mk			tests-obsolete		obsolete,atf
+./usr/tests/usr.bin/make/unit-tests/var-class-env.exptests-obsolete		obsolete,atf
+./usr/tests/usr.bin/make/unit-tests/var-class-env.mk

CVS commit: src

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 16:25:54 UTC 2022

Modified Files:
src/distrib/sets/lists/tests: mi
src/usr.bin/make/unit-tests: Makefile
Added Files:
src/usr.bin/make/unit-tests: var-scope-cmdline.exp var-scope-cmdline.mk
var-scope-env.exp var-scope-env.mk var-scope-global.exp
var-scope-global.mk var-scope-local-legacy.exp
var-scope-local-legacy.mk var-scope-local.exp var-scope-local.mk
var-scope.exp var-scope.mk
Removed Files:
src/usr.bin/make/unit-tests: var-class-cmdline.exp var-class-cmdline.mk
var-class-env.exp var-class-env.mk var-class-global.exp
var-class-global.mk var-class-local-legacy.exp
var-class-local-legacy.mk var-class-local.exp var-class-local.mk
var-class.exp var-class.mk

Log Message:
tests/make: rename var-class to var-scope

There is no such concept as a "variable class" in make, these tests
focus on the variable scope instead.


To generate a diff of this commit:
cvs rdiff -u -r1.1183 -r1.1184 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.298 -r1.299 src/usr.bin/make/unit-tests/Makefile
cvs rdiff -u -r1.4 -r0 src/usr.bin/make/unit-tests/var-class-cmdline.exp
cvs rdiff -u -r1.5 -r0 src/usr.bin/make/unit-tests/var-class-cmdline.mk \
src/usr.bin/make/unit-tests/var-class-local.mk
cvs rdiff -u -r1.1 -r0 src/usr.bin/make/unit-tests/var-class-env.exp \
src/usr.bin/make/unit-tests/var-class-global.exp \
src/usr.bin/make/unit-tests/var-class-local-legacy.exp \
src/usr.bin/make/unit-tests/var-class.exp
cvs rdiff -u -r1.2 -r0 src/usr.bin/make/unit-tests/var-class-env.mk \
src/usr.bin/make/unit-tests/var-class-local-legacy.mk \
src/usr.bin/make/unit-tests/var-class.mk
cvs rdiff -u -r1.3 -r0 src/usr.bin/make/unit-tests/var-class-global.mk \
src/usr.bin/make/unit-tests/var-class-local.exp
cvs rdiff -u -r0 -r1.1 src/usr.bin/make/unit-tests/var-scope-cmdline.exp \
src/usr.bin/make/unit-tests/var-scope-cmdline.mk \
src/usr.bin/make/unit-tests/var-scope-env.exp \
src/usr.bin/make/unit-tests/var-scope-env.mk \
src/usr.bin/make/unit-tests/var-scope-global.exp \
src/usr.bin/make/unit-tests/var-scope-global.mk \
src/usr.bin/make/unit-tests/var-scope-local-legacy.exp \
src/usr.bin/make/unit-tests/var-scope-local-legacy.mk \
src/usr.bin/make/unit-tests/var-scope-local.exp \
src/usr.bin/make/unit-tests/var-scope-local.mk \
src/usr.bin/make/unit-tests/var-scope.exp \
src/usr.bin/make/unit-tests/var-scope.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 16:09:39 UTC 2022

Modified Files:
src/distrib/sets/lists/tests: mi
src/usr.bin/make/unit-tests: Makefile directive-sinclude.exp
directive-sinclude.mk directive-unexport-env.mk
directive-warning.exp directive-warning.mk directive.exp
directive.mk opt-debug-cond.exp opt-debug-cond.mk
opt-debug-curdir.mk opt-debug-var.exp opt-debug-var.mk
opt-debug-x-trace.exp opt-debug-x-trace.mk opt-define.mk
opt-env.exp opt-env.mk opt-jobs-internal.exp opt-jobs-internal.mk
opt-raw.mk opt-silent.exp opt-silent.mk sh.mk var-class-global.mk
varmod-select-words.exp varmod-select-words.mk
Removed Files:
src/usr.bin/make/unit-tests: envfirst.exp envfirst.mk modword.exp
modword.mk

Log Message:
tests/make: extend test suite, move old tests to 2020 scheme

The tests from envfirst.mk are now in opt-env.mk.
The tests from modword.mk are now in varmod-select-words.mk.


To generate a diff of this commit:
cvs rdiff -u -r1.1182 -r1.1183 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.297 -r1.298 src/usr.bin/make/unit-tests/Makefile
cvs rdiff -u -r1.1 -r1.2 src/usr.bin/make/unit-tests/directive-sinclude.exp \
src/usr.bin/make/unit-tests/opt-debug-cond.exp \
src/usr.bin/make/unit-tests/opt-debug-cond.mk \
src/usr.bin/make/unit-tests/opt-debug-curdir.mk \
src/usr.bin/make/unit-tests/opt-debug-var.exp \
src/usr.bin/make/unit-tests/opt-debug-var.mk \
src/usr.bin/make/unit-tests/opt-debug-x-trace.exp \
src/usr.bin/make/unit-tests/opt-debug-x-trace.mk \
src/usr.bin/make/unit-tests/opt-env.exp \
src/usr.bin/make/unit-tests/opt-jobs-internal.exp \
src/usr.bin/make/unit-tests/opt-silent.exp \
src/usr.bin/make/unit-tests/varmod-select-words.exp
cvs rdiff -u -r1.2 -r1.3 src/usr.bin/make/unit-tests/directive-sinclude.mk \
src/usr.bin/make/unit-tests/opt-define.mk \
src/usr.bin/make/unit-tests/opt-env.mk \
src/usr.bin/make/unit-tests/opt-jobs-internal.mk \
src/usr.bin/make/unit-tests/opt-raw.mk \
src/usr.bin/make/unit-tests/opt-silent.mk \
src/usr.bin/make/unit-tests/sh.mk \
src/usr.bin/make/unit-tests/var-class-global.mk
cvs rdiff -u -r1.7 -r1.8 \
src/usr.bin/make/unit-tests/directive-unexport-env.mk
cvs rdiff -u -r1.4 -r1.5 src/usr.bin/make/unit-tests/directive-warning.exp
cvs rdiff -u -r1.6 -r1.7 src/usr.bin/make/unit-tests/directive-warning.mk
cvs rdiff -u -r1.5 -r1.6 src/usr.bin/make/unit-tests/directive.exp \
src/usr.bin/make/unit-tests/directive.mk
cvs rdiff -u -r1.1 -r0 src/usr.bin/make/unit-tests/envfirst.exp
cvs rdiff -u -r1.5 -r0 src/usr.bin/make/unit-tests/envfirst.mk
cvs rdiff -u -r1.4 -r0 src/usr.bin/make/unit-tests/modword.exp
cvs rdiff -u -r1.6 -r0 src/usr.bin/make/unit-tests/modword.mk
cvs rdiff -u -r1.3 -r1.4 src/usr.bin/make/unit-tests/varmod-select-words.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/tests/mi
diff -u src/distrib/sets/lists/tests/mi:1.1182 src/distrib/sets/lists/tests/mi:1.1183
--- src/distrib/sets/lists/tests/mi:1.1182	Wed Jan 19 22:10:41 2022
+++ src/distrib/sets/lists/tests/mi	Sun Jan 23 16:09:38 2022
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1182 2022/01/19 22:10:41 rillig Exp $
+# $NetBSD: mi,v 1.1183 2022/01/23 16:09:38 rillig Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -5659,8 +5659,8 @@
 ./usr/tests/usr.bin/make/unit-tests/doterror.mk	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/dotwait.exp	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/dotwait.mk	tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/envfirst.exptests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/envfirst.mk	tests-usr.bin-tests	compattestfile,atf
+./usr/tests/usr.bin/make/unit-tests/envfirst.exptests-obsolete		obsolete,atf
+./usr/tests/usr.bin/make/unit-tests/envfirst.mk	tests-obsolete		obsolete,atf
 ./usr/tests/usr.bin/make/unit-tests/error.exp	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/error.mk	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/escape.exp	tests-usr.bin-tests	compattestfile,atf
@@ -5723,8 +5723,8 @@
 ./usr/tests/usr.bin/make/unit-tests/modorder.mk	tests-obsolete		obsolete
 ./usr/tests/usr.bin/make/unit-tests/modts.exp	tests-usr.bin-tests	compattestfile,atf
 ./usr/tests/usr.bin/make/unit-tests/modts.mk	tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/modword.exp	tests-usr.bin-tests	compattestfile,atf
-./usr/tests/usr.bin/make/unit-tests/modword.mk	tests-usr.bin-tests	compattestfile,atf
+./usr/tests/usr.bin/make/unit-tests/modword.exp	

CVS commit: src

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 16:09:39 UTC 2022

Modified Files:
src/distrib/sets/lists/tests: mi
src/usr.bin/make/unit-tests: Makefile directive-sinclude.exp
directive-sinclude.mk directive-unexport-env.mk
directive-warning.exp directive-warning.mk directive.exp
directive.mk opt-debug-cond.exp opt-debug-cond.mk
opt-debug-curdir.mk opt-debug-var.exp opt-debug-var.mk
opt-debug-x-trace.exp opt-debug-x-trace.mk opt-define.mk
opt-env.exp opt-env.mk opt-jobs-internal.exp opt-jobs-internal.mk
opt-raw.mk opt-silent.exp opt-silent.mk sh.mk var-class-global.mk
varmod-select-words.exp varmod-select-words.mk
Removed Files:
src/usr.bin/make/unit-tests: envfirst.exp envfirst.mk modword.exp
modword.mk

Log Message:
tests/make: extend test suite, move old tests to 2020 scheme

The tests from envfirst.mk are now in opt-env.mk.
The tests from modword.mk are now in varmod-select-words.mk.


To generate a diff of this commit:
cvs rdiff -u -r1.1182 -r1.1183 src/distrib/sets/lists/tests/mi
cvs rdiff -u -r1.297 -r1.298 src/usr.bin/make/unit-tests/Makefile
cvs rdiff -u -r1.1 -r1.2 src/usr.bin/make/unit-tests/directive-sinclude.exp \
src/usr.bin/make/unit-tests/opt-debug-cond.exp \
src/usr.bin/make/unit-tests/opt-debug-cond.mk \
src/usr.bin/make/unit-tests/opt-debug-curdir.mk \
src/usr.bin/make/unit-tests/opt-debug-var.exp \
src/usr.bin/make/unit-tests/opt-debug-var.mk \
src/usr.bin/make/unit-tests/opt-debug-x-trace.exp \
src/usr.bin/make/unit-tests/opt-debug-x-trace.mk \
src/usr.bin/make/unit-tests/opt-env.exp \
src/usr.bin/make/unit-tests/opt-jobs-internal.exp \
src/usr.bin/make/unit-tests/opt-silent.exp \
src/usr.bin/make/unit-tests/varmod-select-words.exp
cvs rdiff -u -r1.2 -r1.3 src/usr.bin/make/unit-tests/directive-sinclude.mk \
src/usr.bin/make/unit-tests/opt-define.mk \
src/usr.bin/make/unit-tests/opt-env.mk \
src/usr.bin/make/unit-tests/opt-jobs-internal.mk \
src/usr.bin/make/unit-tests/opt-raw.mk \
src/usr.bin/make/unit-tests/opt-silent.mk \
src/usr.bin/make/unit-tests/sh.mk \
src/usr.bin/make/unit-tests/var-class-global.mk
cvs rdiff -u -r1.7 -r1.8 \
src/usr.bin/make/unit-tests/directive-unexport-env.mk
cvs rdiff -u -r1.4 -r1.5 src/usr.bin/make/unit-tests/directive-warning.exp
cvs rdiff -u -r1.6 -r1.7 src/usr.bin/make/unit-tests/directive-warning.mk
cvs rdiff -u -r1.5 -r1.6 src/usr.bin/make/unit-tests/directive.exp \
src/usr.bin/make/unit-tests/directive.mk
cvs rdiff -u -r1.1 -r0 src/usr.bin/make/unit-tests/envfirst.exp
cvs rdiff -u -r1.5 -r0 src/usr.bin/make/unit-tests/envfirst.mk
cvs rdiff -u -r1.4 -r0 src/usr.bin/make/unit-tests/modword.exp
cvs rdiff -u -r1.6 -r0 src/usr.bin/make/unit-tests/modword.mk
cvs rdiff -u -r1.3 -r1.4 src/usr.bin/make/unit-tests/varmod-select-words.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/crypto/dist/ipsec-tools/src/racoon

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 14:55:28 UTC 2022

Modified Files:
src/crypto/dist/ipsec-tools/src/racoon: prsa_par.y

Log Message:
PR/56658: Juraj Hercek: Plain RSA keys are not loaded by racoon IKE daemon


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y
diff -u src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y:1.7 src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y:1.8
--- src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y:1.7	Tue Feb  6 22:59:03 2018
+++ src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y	Sun Jan 23 09:55:28 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: prsa_par.y,v 1.7 2018/02/07 03:59:03 christos Exp $	*/
+/*	$NetBSD: prsa_par.y,v 1.8 2022/01/23 14:55:28 christos Exp $	*/
 
 /* Id: prsa_par.y,v 1.3 2004/11/08 12:04:23 ludvigm Exp */
 
@@ -87,6 +87,15 @@ enum rsa_key_type prsa_cur_type = RSA_TY
 
 static RSA *rsa_cur;
 
+static BIGNUM *bn_n = NULL; /* Modulus */
+static BIGNUM *bn_e = NULL; /* Public Exponent */
+static BIGNUM *bn_d = NULL; /* Private Exponent */
+static BIGNUM *bn_p = NULL; /* Prime1 */
+static BIGNUM *bn_q = NULL; /* Prime2 */
+static BIGNUM *bn_dmp1 = NULL; /* Exponent1 */
+static BIGNUM *bn_dmq1 = NULL; /* Exponent2 */
+static BIGNUM *bn_iqmp = NULL; /* Coefficient */
+
 void
 prsaerror(const char *s, ...)
 {
@@ -174,26 +183,35 @@ statement:
 rsa_statement:
 	TAG_RSA OBRACE params EBRACE
 	{
-		const BIGNUM *n, *e, *d;
-		RSA_get0_key(rsa_cur, , , );
 		if (prsa_cur_type == RSA_TYPE_PUBLIC) {
 			prsawarning("Using private key for public key purpose.\n");
-			if (!n || !e) {
-prsaerror("Incomplete key. Mandatory parameters are missing!\n");
+			if (!bn_n || !bn_e) {
+prsaerror("Either of mandatory public key parameters "
+		" - n, d - are missing!\n");
 YYABORT;
-			}
-		}
-		else {
-			const BIGNUM *p, *q, *dmp1, *dmq1, *iqmp;
-			if (!n || !e || !d) {
-prsaerror("Incomplete key. Mandatory parameters are missing!\n");
+			} else if (1 != RSA_set0_key(rsa_cur, bn_n, bn_e, NULL)) {
+prsaerror("Invalid parameters. Public key not set up!\n");
 YYABORT;
 			}
-			RSA_get0_factors(rsa_cur, , );
-			RSA_get0_crt_params(rsa_cur, , , );
-			if (!p || !q || !dmp1 || !dmq1 || !iqmp) {
-RSA_free(rsa_cur);
-rsa_cur = RSA_new();
+		} else {
+			if (!bn_n || !bn_e || !bn_d) {
+prsaerror("Either of mandatory private key parameters "
+		"- n, e, d -- are missing!\n");
+YYABORT;
+			} else if (1 != RSA_set0_key(rsa_cur, bn_n, bn_e, bn_d)) {
+prsaerror("Can not use mandatory private key parameters!\n");
+YYABORT;
+			} else if (!bn_p || !bn_q || !bn_dmp1 || !bn_dmq1 || !bn_iqmp) {
+/* If any of the suplementary parameters is missing, continue
+ * without setting them up.
+ */
+			} else if (1 != RSA_set0_factors(rsa_cur, bn_p, bn_q)) {
+prsaerror("Invalid p or q parameter. Private key not set up!\n");
+YYABORT;
+			} else if (1 != RSA_set0_crt_params(rsa_cur, bn_dmp1, bn_dmq1, bn_iqmp)) {
+prsaerror("Invalid dmp1, dmq1 or iqmp parameters. "
+		"Private key not set up!\n");
+YYABORT;
 			}
 		}
 		$$ = rsa_cur;
@@ -297,91 +315,75 @@ params:
 param:
 	MODULUS COLON HEX 
 	{ 
-	const BIGNUM *n;
-	RSA_get0_key(rsa_cur, , NULL, NULL);
-	if (!n)
-		RSA_set0_key(rsa_cur, $3, NULL, NULL);
-	else {
-		prsaerror("Modulus already defined\n");
-		YYABORT;
-	}
+		if (bn_n) {
+			prsaerror("Modulus already defined\n");
+			YYABORT;
+		} else {
+			bn_n = $3;
+		}
 	}
 	| PUBLIC_EXPONENT COLON HEX 
 	{ 
-	const BIGNUM *e;
-	RSA_get0_key(rsa_cur, NULL, , NULL);
-	if (!e)
-		RSA_set0_key(rsa_cur, NULL, $3, NULL);
-	else {
-		prsaerror("PublicExponent already defined\n");
-		YYABORT;
-	}
+		if (bn_e) {
+			prsaerror("PublicExponent already defined\n");
+			YYABORT;
+		} else {
+			bn_e = $3;
+		}
 	}
 	| PRIVATE_EXPONENT COLON HEX 
 	{ 
-	const BIGNUM *d;
-	RSA_get0_key(rsa_cur, NULL, NULL, );
-	if (!d)
-		RSA_set0_key(rsa_cur, NULL, NULL, $3);
-	else {
-		prsaerror("PrivateExponent already defined\n");
-		YYABORT;
-	}
+		if (bn_d) {
+			prsaerror("PrivateExponent already defined\n");
+			YYABORT;
+		} else {
+			bn_d = $3;
+		}
 	}
 	| PRIME1 COLON HEX 
 	{ 
-	const BIGNUM *p;
-	RSA_get0_factors(rsa_cur, , NULL);
-	if (!p)
-		RSA_set0_factors(rsa_cur, $3, NULL);
-	else {
-		prsaerror("Prime1 already defined\n");
-		YYABORT;
-	}
+		if (bn_p) {
+			prsaerror("Prime1 already defined\n");
+			YYABORT;
+		} else {
+			bn_p = $3;
+		}
 	}
 	| PRIME2 COLON HEX 
 	{
-	const BIGNUM *q;
-	RSA_get0_factors(rsa_cur, NULL, );
-	if (!q)
-		RSA_set0_factors(rsa_cur, NULL, $3);
-	else {
-		prsaerror("Prime2 already defined\n");
-		YYABORT;
-	}
+		if 

CVS commit: src/crypto/dist/ipsec-tools/src/racoon

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 14:55:28 UTC 2022

Modified Files:
src/crypto/dist/ipsec-tools/src/racoon: prsa_par.y

Log Message:
PR/56658: Juraj Hercek: Plain RSA keys are not loaded by racoon IKE daemon


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/crypto/dist/ipsec-tools/src/racoon/prsa_par.y

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 14:35:45 UTC 2022

Modified Files:
src/crypto/dist/ipsec-tools/src/racoon: plainrsa-gen.c
src/distrib/sets/lists/base: mi
src/distrib/sets/lists/debug: mi
src/distrib/sets/lists/man: mi
src/usr.sbin: Makefile
Added Files:
src/usr.sbin/plainrsa-gen: Makefile

Log Message:
PR/56657: Juraj Hercek: Add plainrsa-gen utility mentioned in racoon.conf(5)
and fix it for OpenSSL 1.1


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 \
src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c
cvs rdiff -u -r1.1288 -r1.1289 src/distrib/sets/lists/base/mi
cvs rdiff -u -r1.371 -r1.372 src/distrib/sets/lists/debug/mi
cvs rdiff -u -r1.1732 -r1.1733 src/distrib/sets/lists/man/mi
cvs rdiff -u -r1.285 -r1.286 src/usr.sbin/Makefile
cvs rdiff -u -r0 -r1.1 src/usr.sbin/plainrsa-gen/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c
diff -u src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c:1.6 src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c:1.7
--- src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c:1.6	Fri Feb 11 05:07:19 2011
+++ src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c	Sun Jan 23 09:35:45 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: plainrsa-gen.c,v 1.6 2011/02/11 10:07:19 tteras Exp $	*/
+/*	$NetBSD: plainrsa-gen.c,v 1.7 2022/01/23 14:35:45 christos Exp $	*/
 
 /* Id: plainrsa-gen.c,v 1.6 2005/04/21 09:08:40 monas Exp */
 /*
@@ -63,6 +63,8 @@
 
 #include "package_version.h"
 
+#define DEFAULT_PUBEXP RSA_F4
+
 void
 usage (char *argv0)
 {
@@ -72,7 +74,7 @@ usage (char *argv0)
 	fprintf(stderr, "Usage: %s [options]\n", argv0);
 	fprintf(stderr, "\n");
 	fprintf(stderr, "  -b bits   Generate  long RSA key (default=1024)\n");
-	fprintf(stderr, "  -e pubexp Public exponent to use (default=0x3)\n");
+	fprintf(stderr, "  -e pubexp Public exponent to use (default=%#x)\n", DEFAULT_PUBEXP);
 	fprintf(stderr, "  -f filename   Filename to store the key to (default=stdout)\n");
 	fprintf(stderr, "  -i filename   Input source for format conversion\n");
 	fprintf(stderr, "  -hHelp\n");
@@ -91,11 +93,11 @@ mix_b64_pubkey(const RSA *key)
 	long binlen, ret;
 	vchar_t *res;
 	
-	binlen = 1 + BN_num_bytes(key->e) + BN_num_bytes(key->n);
+	binlen = 1 + BN_num_bytes(RSA_get0_e(key)) + BN_num_bytes(RSA_get0_n(key));
 	binbuf = malloc(binlen);
 	memset(binbuf, 0, binlen);
-	binbuf[0] = BN_bn2bin(key->e, (unsigned char *) [1]);
-	ret = BN_bn2bin(key->n, (unsigned char *) ([binbuf[0] + 1]));
+	binbuf[0] = BN_bn2bin(RSA_get0_e(key), (unsigned char *) [1]);
+	ret = BN_bn2bin(RSA_get0_n(key), (unsigned char *) ([binbuf[0] + 1]));
 	if (1 + binbuf[0] + ret != binlen) {
 		plog(LLV_ERROR, LOCATION, NULL,
 		 "Pubkey generation failed. This is really strange...\n");
@@ -131,16 +133,16 @@ print_rsa_key(FILE *fp, const RSA *key)
 	
 	fprintf(fp, "# : PUB 0s%s\n", pubkey64->v);
 	fprintf(fp, ": RSA\t{\n");
-	fprintf(fp, "\t# RSA %d bits\n", BN_num_bits(key->n));
+	fprintf(fp, "\t# RSA %d bits\n", BN_num_bits(RSA_get0_n(key)));
 	fprintf(fp, "\t# pubkey=0s%s\n", pubkey64->v);
-	fprintf(fp, "\tModulus: 0x%s\n", lowercase(BN_bn2hex(key->n)));
-	fprintf(fp, "\tPublicExponent: 0x%s\n", lowercase(BN_bn2hex(key->e)));
-	fprintf(fp, "\tPrivateExponent: 0x%s\n", lowercase(BN_bn2hex(key->d)));
-	fprintf(fp, "\tPrime1: 0x%s\n", lowercase(BN_bn2hex(key->p)));
-	fprintf(fp, "\tPrime2: 0x%s\n", lowercase(BN_bn2hex(key->q)));
-	fprintf(fp, "\tExponent1: 0x%s\n", lowercase(BN_bn2hex(key->dmp1)));
-	fprintf(fp, "\tExponent2: 0x%s\n", lowercase(BN_bn2hex(key->dmq1)));
-	fprintf(fp, "\tCoefficient: 0x%s\n", lowercase(BN_bn2hex(key->iqmp)));
+	fprintf(fp, "\tModulus: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_n(key;
+	fprintf(fp, "\tPublicExponent: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_e(key;
+	fprintf(fp, "\tPrivateExponent: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_d(key;
+	fprintf(fp, "\tPrime1: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_p(key;
+	fprintf(fp, "\tPrime2: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_q(key;
+	fprintf(fp, "\tExponent1: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_dmp1(key;
+	fprintf(fp, "\tExponent2: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_dmq1(key;
+	fprintf(fp, "\tCoefficient: 0x%s\n", lowercase(BN_bn2hex(RSA_get0_iqmp(key;
 	fprintf(fp, "  }\n");
 
 	vfree(pubkey64);
@@ -204,13 +206,17 @@ gen_rsa_key(FILE *fp, size_t bits, unsig
 {
 	int ret;
 	RSA *key;
+	BIGNUM *e;
+
+	key = RSA_new();
+	e = BN_new();
+	BN_set_word(e, exp);
 
-	key = RSA_generate_key(bits, exp, NULL, NULL);
-	if (!key) {
+	if (1 != RSA_generate_key_ex(key, bits, e, NULL)) {
 		fprintf(stderr, "RSA_generate_key(): %s\n", eay_strerror());
 		return -1;
 	}
-	
+
 	ret = print_rsa_key(fp, key);
 	RSA_free(key);
 
@@ -222,7 +228,7 @@ main (int argc, char 

CVS commit: src

2022-01-23 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Jan 23 14:35:45 UTC 2022

Modified Files:
src/crypto/dist/ipsec-tools/src/racoon: plainrsa-gen.c
src/distrib/sets/lists/base: mi
src/distrib/sets/lists/debug: mi
src/distrib/sets/lists/man: mi
src/usr.sbin: Makefile
Added Files:
src/usr.sbin/plainrsa-gen: Makefile

Log Message:
PR/56657: Juraj Hercek: Add plainrsa-gen utility mentioned in racoon.conf(5)
and fix it for OpenSSL 1.1


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 \
src/crypto/dist/ipsec-tools/src/racoon/plainrsa-gen.c
cvs rdiff -u -r1.1288 -r1.1289 src/distrib/sets/lists/base/mi
cvs rdiff -u -r1.371 -r1.372 src/distrib/sets/lists/debug/mi
cvs rdiff -u -r1.1732 -r1.1733 src/distrib/sets/lists/man/mi
cvs rdiff -u -r1.285 -r1.286 src/usr.sbin/Makefile
cvs rdiff -u -r0 -r1.1 src/usr.sbin/plainrsa-gen/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/fdt

2022-01-23 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Sun Jan 23 08:01:33 UTC 2022

Modified Files:
src/sys/dev/fdt: arasan_sdhc_fdt.c

Log Message:
Use __MASK(4) in bus_dmatag_subregion.  NFCI.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/dev/fdt/arasan_sdhc_fdt.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/fdt/arasan_sdhc_fdt.c
diff -u src/sys/dev/fdt/arasan_sdhc_fdt.c:1.7 src/sys/dev/fdt/arasan_sdhc_fdt.c:1.8
--- src/sys/dev/fdt/arasan_sdhc_fdt.c:1.7	Mon Jan 17 14:00:47 2022
+++ src/sys/dev/fdt/arasan_sdhc_fdt.c	Sun Jan 23 08:01:33 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: arasan_sdhc_fdt.c,v 1.7 2022/01/17 14:00:47 skrll Exp $ */
+/* $NetBSD: arasan_sdhc_fdt.c,v 1.8 2022/01/23 08:01:33 skrll Exp $ */
 
 /*-
  * Copyright (c) 2019 Jared McNeill 
@@ -27,7 +27,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: arasan_sdhc_fdt.c,v 1.7 2022/01/17 14:00:47 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: arasan_sdhc_fdt.c,v 1.8 2022/01/23 08:01:33 skrll Exp $");
 
 #include 
 #include 
@@ -272,7 +272,7 @@ arasan_sdhc_attach(device_t parent, devi
 
 	const uint32_t caps = bus_space_read_4(sc->sc_bst, sc->sc_bsh, SDHC_CAPABILITIES);
 	if ((caps & (SDHC_ADMA2_SUPP|SDHC_64BIT_SYS_BUS)) == SDHC_ADMA2_SUPP) {
-		error = bus_dmatag_subregion(faa->faa_dmat, 0, UINT32_MAX,
+		error = bus_dmatag_subregion(faa->faa_dmat, 0, __MASK(32),
 		>sc_base.sc_dmat, BUS_DMA_WAITOK);
 		if (error != 0) {
 			aprint_error(": couldn't create DMA tag: %d\n", error);



CVS commit: src/sys/dev/fdt

2022-01-23 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Sun Jan 23 08:01:33 UTC 2022

Modified Files:
src/sys/dev/fdt: arasan_sdhc_fdt.c

Log Message:
Use __MASK(4) in bus_dmatag_subregion.  NFCI.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/dev/fdt/arasan_sdhc_fdt.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Index: src/usr.bin/make/make.h
diff -u src/usr.bin/make/make.h:1.289 src/usr.bin/make/make.h:1.290
--- src/usr.bin/make/make.h:1.289	Sat Jan 15 19:13:08 2022
+++ src/usr.bin/make/make.h	Sun Jan 23 22:12:16 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: make.h,v 1.289 2022/01/15 19:13:08 rillig Exp $	*/
+/*	$NetBSD: make.h,v 1.290 2022/01/23 22:12:16 rillig Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -74,7 +74,7 @@
 
 /*
  * make.h --
  *	The global definitions for pmake
  */
 
 #ifndef MAKE_MAKE_H
@@ -758,8 +758,260 @@ typedef struct CmdOpts {
 
 extern CmdOpts opts;
 
-#include "nonints.h"
+/* arch.c */
+void Arch_Init(void);
+void Arch_End(void);
+
+bool Arch_ParseArchive(char **, GNodeList *, GNode *);
+void Arch_Touch(GNode *);
+void Arch_TouchLib(GNode *);
+void Arch_UpdateMTime(GNode *gn);
+void Arch_UpdateMemberMTime(GNode *gn);
+void Arch_FindLib(GNode *, SearchPath *);
+bool Arch_LibOODate(GNode *) MAKE_ATTR_USE;
+bool Arch_IsLib(GNode *) MAKE_ATTR_USE;
+
+/* compat.c */
+bool Compat_RunCommand(const char *, GNode *, StringListNode *);
+void Compat_Run(GNodeList *);
+void Compat_Make(GNode *, GNode *);
+
+/* cond.c */
+CondResult Cond_EvalCondition(const char *) MAKE_ATTR_USE;
+CondResult Cond_EvalLine(const char *) MAKE_ATTR_USE;
+void Cond_restore_depth(unsigned int);
+unsigned int Cond_save_depth(void) MAKE_ATTR_USE;
 
+/* dir.c; see also dir.h */
+
+MAKE_INLINE const char * MAKE_ATTR_USE
+str_basename(const char *pathname)
+{
+	const char *lastSlash = strrchr(pathname, '/');
+	return lastSlash != NULL ? lastSlash + 1 : pathname;
+}
+
+MAKE_INLINE SearchPath * MAKE_ATTR_USE
+SearchPath_New(void)
+{
+	SearchPath *path = bmake_malloc(sizeof *path);
+	Lst_Init(>dirs);
+	return path;
+}
+
+void SearchPath_Free(SearchPath *);
+
+/* for.c */
+struct ForLoop;
+int For_Eval(const char *) MAKE_ATTR_USE;
+bool For_Accum(const char *, int *) MAKE_ATTR_USE;
+void For_Run(int, int);
+bool For_NextIteration(struct ForLoop *, Buffer *);
+char *ForLoop_Details(struct ForLoop *);
+void ForLoop_Free(struct ForLoop *);
+
+/* job.c */
+void JobReapChild(pid_t, int, bool);
+
+/* main.c */
+void Main_ParseArgLine(const char *);
+char *Cmd_Exec(const char *, char **) MAKE_ATTR_USE;
+void Error(const char *, ...) MAKE_ATTR_PRINTFLIKE(1, 2);
+void Fatal(const char *, ...) MAKE_ATTR_PRINTFLIKE(1, 2) MAKE_ATTR_DEAD;
+void Punt(const char *, ...) MAKE_ATTR_PRINTFLIKE(1, 2) MAKE_ATTR_DEAD;
+void DieHorribly(void) MAKE_ATTR_DEAD;
+void Finish(int) MAKE_ATTR_DEAD;
+bool unlink_file(const char *) MAKE_ATTR_USE;
+void execDie(const char *, const char *);
+char *getTmpdir(void) MAKE_ATTR_USE;
+bool ParseBoolean(const char *, bool) MAKE_ATTR_USE;
+const char *cached_realpath(const char *, char *);
+
+/* parse.c */
+void Parse_Init(void);
+void Parse_End(void);
+
+void Parse_Error(ParseErrorLevel, const char *, ...) MAKE_ATTR_PRINTFLIKE(2, 3);
+bool Parse_VarAssign(const char *, bool, GNode *) MAKE_ATTR_USE;
+void Parse_AddIncludeDir(const char *);
+void Parse_File(const char *, int);
+void Parse_PushInput(const char *, int, int, Buffer, struct ForLoop *);
+void Parse_MainName(GNodeList *);
+int Parse_NumErrors(void) MAKE_ATTR_USE;
+
+
+/* suff.c */
+void Suff_Init(void);
+void Suff_End(void);
+
+void Suff_ClearSuffixes(void);
+bool Suff_IsTransform(const char *) MAKE_ATTR_USE;
+GNode *Suff_AddTransform(const char *);
+void Suff_EndTransform(GNode *);
+void Suff_AddSuffix(const char *);
+SearchPath *Suff_GetPath(const char *) MAKE_ATTR_USE;
+void Suff_ExtendPaths(void);
+void Suff_AddInclude(const char *);
+void Suff_AddLib(const char *);
+void Suff_FindDeps(GNode *);
+SearchPath *Suff_FindPath(GNode *) MAKE_ATTR_USE;
+void Suff_SetNull(const char *);
+void Suff_PrintAll(void);
+char *Suff_NamesStr(void) MAKE_ATTR_USE;
+
+/* targ.c */
+void Targ_Init(void);
+void Targ_End(void);
+
+void Targ_Stats(void);
+GNodeList *Targ_List(void) MAKE_ATTR_USE;
+GNode *GNode_New(const char *) MAKE_ATTR_USE;
+GNode *Targ_FindNode(const char *) MAKE_ATTR_USE;
+GNode *Targ_GetNode(const char *) MAKE_ATTR_USE;
+GNode *Targ_NewInternalNode(const char *) MAKE_ATTR_USE;
+GNode *Targ_GetEndNode(void);
+void Targ_FindList(GNodeList *, StringList *);
+void Targ_PrintCmds(GNode *);
+void Targ_PrintNode(GNode *, int);
+void Targ_PrintNodes(GNodeList *, int);
+const char *Targ_FmtTime(time_t) MAKE_ATTR_USE;
+void Targ_PrintType(GNodeType);
+void Targ_PrintGraph(int);
+void Targ_Propagate(void);
@@ -74,7 +74,7 @@
 /*
  * make.h --
- *	The global definitions for pmake
+ *	The global definitions for make
  */
 

CVS commit: src/usr.bin/make

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 22:12:16 UTC 2022

Modified Files:
src/usr.bin/make: make.h
Removed Files:
src/usr.bin/make: nonints.h

Log Message:
make: merge nonints.h into make.h

No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.289 -r1.290 src/usr.bin/make/make.h
cvs rdiff -u -r1.239 -r0 src/usr.bin/make/nonints.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/usr.bin/make/unit-tests

2022-01-23 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Sun Jan 23 21:48:59 UTC 2022

Modified Files:
src/usr.bin/make/unit-tests: deptgt-main.exp deptgt-main.mk
directive-dinclude.exp directive-dinclude.mk
directive-hyphen-include.exp directive-hyphen-include.mk
directive-if.exp directive-if.mk directive-ifdef.exp
directive-ifdef.mk directive-sinclude.mk varmod-to-separator.mk
varname-dot-make-pid.mk varname-dot-make-ppid.mk

Log Message:
tests/make: add a few more tests


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/usr.bin/make/unit-tests/deptgt-main.exp \
src/usr.bin/make/unit-tests/directive-dinclude.exp \
src/usr.bin/make/unit-tests/directive-dinclude.mk \
src/usr.bin/make/unit-tests/directive-hyphen-include.exp \
src/usr.bin/make/unit-tests/directive-hyphen-include.mk
cvs rdiff -u -r1.3 -r1.4 src/usr.bin/make/unit-tests/deptgt-main.mk \
src/usr.bin/make/unit-tests/directive-ifdef.exp \
src/usr.bin/make/unit-tests/directive-sinclude.mk
cvs rdiff -u -r1.9 -r1.10 src/usr.bin/make/unit-tests/directive-if.exp \
src/usr.bin/make/unit-tests/varmod-to-separator.mk
cvs rdiff -u -r1.10 -r1.11 src/usr.bin/make/unit-tests/directive-if.mk
cvs rdiff -u -r1.4 -r1.5 src/usr.bin/make/unit-tests/directive-ifdef.mk
cvs rdiff -u -r1.2 -r1.3 src/usr.bin/make/unit-tests/varname-dot-make-pid.mk \
src/usr.bin/make/unit-tests/varname-dot-make-ppid.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
